@@ -29,4 +29,17 @@ bbrier = function(truth, prob, positive, sample_weights = NULL, ...) {
 }
 
 #' @include measures.R
-add_measure(bbrier, "Binary Brier Score", "binary", 0, 1, TRUE)
+add_measure(bbrier, "Binary Brier Score", "binary", 0, 1, TRUE, obs_loss = "se_binary")
+
+
+#' @title Binary Squared Error
+#'
+#' @description
+#' Observation-wise loss function for [bbrier()].
+#'
+#' @export
+#' @keywords internal
+se_binary = function(truth, prob, positive, ...) {
+  assert_binary(truth, prob = prob, positive = positive)
+  ((truth == positive) - prob)^2
+}
